@@ -34,6 +34,7 @@ class authres_status extends rcube_plugin
         "domainkeys",
         "sender-id",
         "spf",
+        "dmarc",
         "arc",
     );
 
@@ -141,7 +142,7 @@ class authres_status extends rcube_plugin
                     $args['blocks']['authresstatus']['name'] = $this->gettext('title_include_status');
 
                     $args['blocks']['authresstatus']['options']['enable' . $status]['title'] = $this->gettext('label_include_status' . $status);
-                    $input = new html_checkbox(array('name' => '_show_statuses[]', 'id' => 'enable_authres_status_column', 'value' => $status));
+                    $input = new html_checkbox(array('name' => '_show_statuses[]', 'id' => 'enable_authres_status_' . $status, 'value' => $status));
                     $args['blocks']['authresstatus']['options']['enable' . $status]['content'] = $input->show(($show_statuses & $status));
                 }
             }
@@ -252,7 +253,7 @@ class authres_status extends rcube_plugin
     }
 	
 	public function message_summary($p){
-	return array('content' => preg_replace('/(<span>\s*)()(From)/', '$1' . $this->img_status . ' $3', $p['content']));
+	return array('content' => preg_replace('/(<span>.*)(<span class="adr">)/', '$1' . $this->img_status . ' $2 ', $p['content']));
 	}
 	
     /* See https://tools.ietf.org/html/rfc5451
@@ -297,7 +298,7 @@ class authres_status extends rcube_plugin
                 }
 
                 foreach ($resinfos as $resinfo) {
-                    if (preg_match('/(' . implode("|", self::$RFC5451_authentication_methods) . ')' . $cfws . '=' . $cfws . '(' . implode("|", array_keys(self::$RFC5451_authentication_results)) . ')' . $cfws . '(\(.*?\))?/i', $resinfo, $m, PREG_OFFSET_CAPTURE)) {
+                    if (preg_match('/^(' . implode("|", self::$RFC5451_authentication_methods) . ')' . $cfws . '=' . $cfws . '(' . implode("|", array_keys(self::$RFC5451_authentication_results)) . ')' . $cfws . '(\(.*?\))?/i', $resinfo, $m, PREG_OFFSET_CAPTURE)) {
                         $parsed_resinfo = array(
                             'title'  => trim($m[0][0]),
                             'method' => $m[1][0],
